@@ -1,28 +1,22 @@
-'''
+import random 
+import datetime
+import importlib
+import math
+
 import numpy as np 
 import pandas as pd 
 import tensorflow as tf 
 from tensorflow.contrib.layers import fully_connected as FC_Net 
 from sklearn.metrics import brier_score_loss 
 from sklearn.model_selection import train_test_split 
-import random 
 from lifelines import KaplanMeierFitter 
-
 import matplotlib.pyplot as plt 
-import math 
 from sklearn.metrics import roc_auc_score
 from sklearn.preprocessing import LabelEncoder
-
 import sklearn.metrics as metrics
-
-import datetime
-
 from termcolor import colored
-import importlib
-
 from scipy import stats
-import math
-'''
+
 '''
 This declare DeepHit architecture:
 
@@ -44,19 +38,36 @@ LOSS FUNCTIONS:
     - 3. calibration loss (this is to reduce the calibration loss; this is not included in the paper version)
 '''
 
-from myimports import *
-
+     
+global _EPSILON
 _EPSILON = 1e-08
 
 
+def test(x):
+    print('x = ', x)
+
 
 ##### USER-DEFINED FUNCTIONS
 def log(x):
-    return tf.log(x + _EPSILON)
+    #print('logX')
+    #tf.log is deprecated. Please use tf.math.log instead.
+    return tf.math.log(x + _EPSILON)
 
 def div(x, y):
+    #print('divXY')
     return tf.div(x, (y + _EPSILON))
 
+def load_dffromCsv(dfname):
+    dir='/dbfs/user/hive/warehouse/'
+    df=dh.pd.read_csv(dir+dfname)
+    print(dfname, 'loaded!')
+    return df
+
+def save_dftoCsv(df, dfname):
+    dir='/dbfs/user/hive/warehouse/'
+    df.to_csv(dir+dfname, index = False)
+    print(dfname, 'saved!')
+
 
 class Model_DeepHit:
     def __init__(self, sess, name, input_dims, network_settings):
@@ -126,8 +137,9 @@ class Model_DeepHit:
             self.loss_Ranking()             #get loss2: Ranking loss
             self.loss_Calibration()         #get loss3: Calibration loss
 
-            self.LOSS_TOTAL = self.a*self.LOSS_1 + self.b*self.LOSS_2 + self.c*self.LOSS_3
-            self.solver = tf.train.AdamOptimizer(learning_rate=self.lr_rate).minimize(self.LOSS_TOTAL)
+            self.LOSS_TOTAL = self.a*self.LOSS_1 + self.b*self.LOSS_2 + self.c*self.LOSS_3  ## diff from original
+            #tf.train.AdamOptimizer is deprecated. Please use tf.compat.v1.train.AdamOptimizer instead.
+            self.solver =  tf.compat.v1.train.AdamOptimizer(learning_rate=self.lr_rate).minimize(self.LOSS_TOTAL)
 
 
     ### LOSS-FUNCTION 1 -- Log-likelihood loss
@@ -135,11 +147,12 @@ class Model_DeepHit:
         I_1 = tf.sign(self.k)
 
         #for uncenosred: log P(T=t,K=k|x)
-        tmp1 = tf.reduce_sum(tf.reduce_sum(self.fc_mask1 * self.out, reduction_indices=2), reduction_indices=1, keep_dims=True)
+        #keep_dims is deprecated, use keepdims instead
+        tmp1 = tf.reduce_sum(tf.reduce_sum(self.fc_mask1 * self.out, reduction_indices=2), reduction_indices=1, keepdims=True)
         tmp1 = I_1 * log(tmp1)
 
         #for censored: log \sum P(T>t|x)
-        tmp2 = tf.reduce_sum(tf.reduce_sum(self.fc_mask1 * self.out, reduction_indices=2), reduction_indices=1, keep_dims=True)
+        tmp2 = tf.reduce_sum(tf.reduce_sum(self.fc_mask1 * self.out, reduction_indices=2), reduction_indices=1, keepdims=True)
         tmp2 = (1. - I_1) * log(tmp2)
 
         self.LOSS_1 = - tf.reduce_mean(tmp1 + 1.0*tmp2)
@@ -152,16 +165,18 @@ class Model_DeepHit:
         
         sigma1 = tf.constant(0.65, dtype=tf.float32)
         eta = []
+        #tf.diag is deprecated. Please use tf.linalg.tensor_diag instead.
+        #tf.diag_part is deprecated. Please use tf.linalg.tensor_diag_part instead.
         for e in range(self.num_Event):
             one_vector = tf.ones_like(self.t, dtype=tf.float32)
             I_2 = tf.cast(tf.equal(self.k, e+1), dtype = tf.float32) #indicator for event
-            I_2 = tf.diag(tf.squeeze(I_2))
+            I_2 = tf.linalg.tensor_diag(tf.squeeze(I_2))
             tmp_e = tf.reshape(tf.slice(self.out, [0, e, 0], [-1, 1, -1]), [-1, self.num_Category]) #event specific joint prob.
 
             R = tf.matmul(tmp_e, tf.transpose(self.fc_mask2)) #no need to divide by each individual dominator
             # r_{ij} = risk of i-th pat based on j-th time-condition (last meas. time ~ event time) , i.e. r_i(T_{j})
 
-            diag_R = tf.reshape(tf.diag_part(R), [-1, 1])
+            diag_R = tf.reshape(tf.linalg.tensor_diag_part(R), [-1, 1])
             R = tf.matmul(one_vector, tf.transpose(diag_R)) - R # R_{ij} = r_{j}(T_{j}) - r_{i}(T_{j})
             R = tf.transpose(R)                                 # Now, R_{ij} (i-th row j-th column) = r_{i}(T_{i}) - r_{j}(T_{i})
 
@@ -169,12 +184,12 @@ class Model_DeepHit:
             # T_{ij}=1 if t_i < t_j  and T_{ij}=0 if t_i >= t_j
 
             T = tf.matmul(I_2, T) # only remains T_{ij}=1 when event occured for subject i
-
-            tmp_eta = tf.reduce_mean(T * tf.exp(-R/sigma1), reduction_indices=1, keep_dims=True)
+            #keep_dims is deprecated, use keepdims instead
+            tmp_eta = tf.reduce_mean(T * tf.exp(-R/sigma1), reduction_indices=1, keepdims=True)
 
             eta.append(tmp_eta)
         eta = tf.stack(eta, axis=1) #stack referenced on subjects
-        eta = tf.reduce_mean(tf.reshape(eta, [-1, self.num_Event]), reduction_indices=1, keep_dims=True)
+        eta = tf.reduce_mean(tf.reshape(eta, [-1, self.num_Event]), reduction_indices=1, keepdims=True)
 
         self.LOSS_2 = tf.reduce_sum(eta) #sum over num_Events
 
@@ -189,11 +204,11 @@ class Model_DeepHit:
             tmp_e = tf.reshape(tf.slice(self.out, [0, e, 0], [-1, 1, -1]), [-1, self.num_Category]) #event specific joint prob.
 
             r = tf.reduce_sum(tmp_e * self.fc_mask2, axis=0) #no need to divide by each individual dominator
-            tmp_eta = tf.reduce_mean((r - I_2)**2, reduction_indices=1, keep_dims=True)
+            tmp_eta = tf.reduce_mean((r - I_2)**2, reduction_indices=1, keepdims=True)
 
             eta.append(tmp_eta)
         eta = tf.stack(eta, axis=1) #stack referenced on subjects
-        eta = tf.reduce_mean(tf.reshape(eta, [-1, self.num_Event]), reduction_indices=1, keep_dims=True)
+        eta = tf.reduce_mean(tf.reshape(eta, [-1, self.num_Event]), reduction_indices=1, keepdims=True)
 
         self.LOSS_3 = tf.reduce_sum(eta) #sum over num_Events
 
@@ -527,7 +542,8 @@ def impt_f_get_fc_mask3(time, meas_time, num_Category):
 def impt_import_dataset_SYNTHETIC(norm_mode='standard'):
     #in_filename = './sample data/nbm/train.csv'
     #df = pd.read_csv(in_filename, sep=',')
-    df = pd_train_sml
+    # orig df = pd_train_sml
+    df = load_dffromCsv('pd_train_sml.csv')
     
     label           = np.asarray(df[['icudeath']] + 1)
     time            = np.asarray(df[['iculos']])
@@ -553,7 +569,8 @@ def impt_import_dataset_SYNTHETIC(norm_mode='standard'):
 def impt_import_dataset_xliu(norm_mode='standard'):
     #in_filename = './sample data/nbm/test.csv'
     #df = pd.read_csv(in_filename, sep=',')
-    df = pd_test_dummy
+    # orig df = pd_test_dummy
+    df = load_dffromCsv('pd_test_dummy.csv')
     
     label           = np.asarray(df[['icudeath']] + 1)
     time            = np.asarray(df[['iculos']])
